//
//  MoodListingViewController.m
//  AppSettings
//
//  Created by Brian Moakley on 5/30/14.
//  Copyright (c) 2014 Razeware. All rights reserved.
//

#import "MoodListingViewController.h"
#import "MoodViewController.h"
#import "RWTMood.h"
#import "MoodXMLParser.h"
#import "XMLWriter.h"

@interface MoodListingViewController ()<UINavigationBarDelegate, UITableViewDataSource, UITableViewDelegate>;

@property (weak, nonatomic) IBOutlet UITableView * tableView;
@property (strong, nonatomic) NSMutableArray * moodList;
@property (strong, nonatomic) RWTMood * selectedMood;

@end

@implementation MoodListingViewController

-(IBAction) addNewMoodItem: (id) sender
{
    self.selectedMood = [[RWTMood alloc] init];
    self.selectedMood.isNew = YES;
    self.selectedMood.dateRecorded = [[NSDate alloc] init];
    [self performSegueWithIdentifier:@"moodModal" sender:nil];
}


-(void) prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender
{
    if ([segue.identifier isEqualToString:@"moodModal"])
    {
        MoodViewController * moodViewController = segue.destinationViewController;
        moodViewController.currentMood = self.selectedMood;
    }
}

-(IBAction) closeMoodController: (UIStoryboardSegue *) exitSegue
{
    if (self.selectedMood.isNew)
    {
        [self.moodList addObject:self.selectedMood];
        [self saveXML];
    }
    [self.tableView reloadData];
}

-(NSInteger) tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    return self.moodList.count;
}

-(UITableViewCell *) tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    UITableViewCell * cell = [self.tableView dequeueReusableCellWithIdentifier:@"MoodCell" forIndexPath:indexPath];
    if (cell)
    {
        RWTMood * mood = self.moodList[indexPath.row];
        cell.textLabel.text = [NSString stringWithFormat:@"%@ %@ - %@", mood.firstName, mood.lastName, mood.dateRecorded];
    }
    return cell;
}

-(void) tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
    self.selectedMood = self.moodList[indexPath.row] ;
    [self performSegueWithIdentifier:@"moodModal" sender:nil];
}

-(UIBarPosition) positionForBar:(id<UIBarPositioning>)bar
{
    return UIBarPositionTopAttached;
}

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self) {
        // Custom initialization
    }
    return self;
}

- (void)viewDidLoad
{
    [super viewDidLoad];
    self.tableView.dataSource = self;
    self.tableView.delegate = self;
    
    NSFileManager * fileManager = [NSFileManager defaultManager];
    NSURL * documentDirectory = [fileManager URLForDirectory:NSDocumentDirectory inDomain:NSUserDomainMask appropriateForURL:nil create:NO error:nil];
    NSURL * saveFile = [documentDirectory URLByAppendingPathComponent:@"save.xml"];

    NSError * error;
    NSData * xmlData;
    NSString * xmlContent = [[NSString alloc] initWithContentsOfURL:saveFile encoding:NSUTF8StringEncoding error:&error];

    if (xmlContent)
    {
        xmlData = [xmlContent dataUsingEncoding:NSUTF8StringEncoding];
    }
    else
    {
        NSString * path = [[NSBundle mainBundle] pathForResource:@"sample_data" ofType:@"xml"];
        NSURL * xmlFile = [NSURL fileURLWithPath:path];
        xmlData = [NSData dataWithContentsOfURL:xmlFile];
    }

    MoodXMLParser * moodParser = [[MoodXMLParser alloc] initWithXMLData:xmlData];
    self.moodList = [[moodParser parseXML] mutableCopy];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
}

-(void) saveXML
{
    NSFileManager * fileManager = [NSFileManager defaultManager];
    NSURL * documentDirectory = [fileManager URLForDirectory:NSDocumentDirectory inDomain:NSUserDomainMask appropriateForURL:nil create:NO error:nil];
    NSURL * saveFile = [documentDirectory URLByAppendingPathComponent:@"save.xml"];
    
    XMLWriter * writer = [[XMLWriter alloc] init];
    [writer writeStartDocumentWithEncodingAndVersion:@"UTF-8" version:@"1.0"];
    [writer writeStartElement:@"entries"];
    
    for (RWTMood * mood in self.moodList)
    {
        [writer writeStartElement:@"entry"];
        
            [writer writeStartElement:@"firstName"];
            [writer writeCharacters:mood.firstName];
            [writer writeEndElement];
        
            [writer writeStartElement:@"lastName"];
            [writer writeCharacters:mood.lastName];
            [writer writeEndElement];

            [writer writeStartElement:@"selectedMood"];
            [writer writeCharacters:[NSString stringWithFormat:@"%d", mood.selectedMood]];
            [writer writeEndElement];
        

            [writer writeStartElement:@"moodReason"];
            [writer writeCData:mood.moodReason];
            [writer writeEndElement];

            [writer writeStartElement:@"dateRecorded"];
            NSDateFormatter * dateFormatter = [[NSDateFormatter alloc] init];
            [dateFormatter setDateFormat:@"yyyy-MM-dd"];
            NSString * dateRecorded = [dateFormatter stringFromDate:mood.dateRecorded];
            [writer writeCharacters:dateRecorded];
            [writer writeEndElement];
        
        [writer writeEndElement];
    }
    [writer writeEndElement];
    [writer writeEndDocument];
    
    NSString * xml = [writer toString];
    [xml writeToURL:saveFile atomically:YES encoding:NSUTF8StringEncoding error:nil];
    
}


@end
