//
//  MoodXMLParser.m
//  AppSettings
//
//  Created by Brian Moakley on 5/30/14.
//  Copyright (c) 2014 Razeware. All rights reserved.
//

#import "MoodXMLParser.h"
#import "RWTMood.h"
#import "RXMLElement.h"

@interface MoodXMLParser()<NSXMLParserDelegate>

@property (strong, nonatomic) NSMutableArray * moodList;
@property (strong, nonatomic) RWTMood * currentMood;
@property (strong, nonatomic) NSData * xmlData;

@end

@implementation MoodXMLParser

-(instancetype) initWithXMLData:(NSData *)xmlData
{
    self = [super init];
    if (self)
    {
        _xmlData = xmlData;
        _moodList = [[NSMutableArray alloc] init];
    }
    return self;
}

-(NSArray *) parseXML
{
    RXMLElement * xml = [RXMLElement elementFromXMLData:self.xmlData];

    __weak MoodXMLParser *weakSelf = self;
    [xml iterate:@"entry" usingBlock:^(RXMLElement * entry) {
        RWTMood * newMood = [RWTMood alloc];
        newMood.firstName = [entry child:@"firstName"].text;
        newMood.lastName = [entry child:@"lastName"].text;
        
        NSString * reason = [entry child:@"moodReason"].text;
        newMood.moodReason = [reason stringByTrimmingCharactersInSet:[NSCharacterSet whitespaceAndNewlineCharacterSet]];

        NSDateFormatter * dateFormatter = [[NSDateFormatter alloc] init];
        [dateFormatter setDateFormat:@"yyyy-MM-dd"];
        NSString * moodDate = [[entry child:@"dateRecorded"].text stringByTrimmingCharactersInSet:[NSCharacterSet whitespaceAndNewlineCharacterSet]];
        newMood.dateRecorded = [dateFormatter dateFromString:moodDate];
        [weakSelf.moodList addObject:newMood];
    }];
    
    return self.moodList;
}



@end
